@@ -7,12 +7,13 @@ docker rmi tango_python_tue
 from zipfile import ZipFile
 from os.path import basename
 import os
+import inspect
 import shutil
 from jinja2 import Environment, FileSystemLoader
 import glob
-import pickle
 from src.unitgrade.framework import Report
 from unitgrade_private import docker_helpers
+from importlib.machinery import SourceFileLoader
 
 COURSES_BASE = "/home/tuhe/Autolab/courses/AutoPopulated"
 
@@ -33,7 +34,7 @@ def jj(source, dest, data):
 
 
 def docker_build_image():
-    os.system(f"cd {CURDIR}/docker_tango_python && docker build --tag tango_python_tue .")
+    os.system(f"cd {CURDIR + '/../../../docker_images'}/docker_tango_python && docker build --tag tango_python_tue .")
     pass
 
 def jj_handout(source, dest, data):
@@ -55,23 +56,17 @@ def zipFilesInDir(dirName, zipFileName, filter):
 
 def paths2report(base_path, report_file):
     mod = ".".join(os.path.relpath(report_file[:-3], base_path).split(os.sep))
-    # f2 = "/home/tuhe/Documents/unitgrade_private_v1/examples/example_simplest/instructor/programs"
-    # spec1 = importlib.util.spec_from_file_location("programs", f2)
-    # programs = importlib.util.module_from_spec(spec1)
-    # spec1.loader.exec_module(programs)
-
-    from importlib.machinery import SourceFileLoader
     foo = SourceFileLoader(mod, report_file).load_module()
     # return foo.Report1
     # spec = importlib.util.spec_from_file_location(mod, report_file)
     # foo = importlib.util.module_from_spec(spec)
-    # spec.loader.exec_module(foo)
     for name, obj in inspect.getmembers(foo):
-        if inspect.isclass(obj): # and obj.__module__ == foo:
-            if obj.__module__ == foo.__name__: # and issubclass(obj, Report):
-                if issubclass(obj, Report):
-                    report = getattr(foo, name)
-                    return report
+        if inspect.isclass(obj):
+            # Last condition could be # and issubclass(obj, Report): but this is not safe when there are two
+            # versions of unitgrade installed (git clone and pip installed package). So use this.
+            if obj.__module__ == foo.__name__ and Report.__name__ in [c.__name__ for c in obj.mro()]:
+                report = getattr(foo, name)
+                return report
     return None
 
 def run_relative(file, base):
@@ -80,13 +75,10 @@ def run_relative(file, base):
     os.system(f"cd {base} && python -m {'.'.join(mod)}")
 
 
-import inspect
-
-
-
 def deploy_assignment(base_name, INSTRUCTOR_BASE, INSTRUCTOR_GRADE_FILE, STUDENT_BASE, STUDENT_GRADE_FILE,
                       output_tar=None,
-                      COURSES_BASE=None):
+                      COURSES_BASE=None,
+                      autograde_image='tango_python_tue'):
 
     assert os.path.isfile(INSTRUCTOR_GRADE_FILE)
     assert os.path.isfile(STUDENT_GRADE_FILE)
@@ -108,8 +100,10 @@ def deploy_assignment(base_name, INSTRUCTOR_BASE, INSTRUCTOR_GRADE_FILE, STUDENT
     # Get the instructor result file.
     run_relative(INSTRUCTOR_GRADE_FILE, INSTRUCTOR_BASE)
     f = glob.glob(os.path.dirname(INSTRUCTOR_GRADE_FILE) + "/*.token")[0]
-    with open(f, 'rb') as f:
-        res = pickle.load(f)
+    from unitgrade_private import load_token
+    res, _ = load_token(f)
+    # with open(f, 'rb') as f:
+    #     res = pickle.load(f)
 
     # Now we have the instructor token file. Let's get the student token file.
     problems = [dict(name='Total', description='', max_score=res['total'][1], optional='false')]
@@ -152,7 +146,7 @@ def deploy_assignment(base_name, INSTRUCTOR_BASE, INSTRUCTOR_GRADE_FILE, STUDENT
             # 'nice_name': base_name + "please",
             'display_name': paths2report(INSTRUCTOR_BASE, INSTRUCTOR_REPORT_FILE).title,
             'handin_filename': handin_filename,
-            'autograde_image': 'tango_python_tue',
+            'autograde_image': autograde_image,
             'src_files_to_handout': ['driver_python.py', 'student_sources.zip', handin_filename, os.path.basename(docker_helpers.__file__),
                                      os.path.basename(INSTRUCTOR_GRADE_FILE)], # Remove tname later; it is the upload.
             'instructor_grade_file': os.path.basename(INSTRUCTOR_GRADE_FILE),
