@@ -21,6 +21,9 @@ def compile_docker_image(Dockerfile, tag=None):
 
 def student_token_file_runner(host_tmp_dir, student_token_file, instructor_grade_script, grade_file_relative_destination):
     """
+
+    Use by autolab code.
+
     :param Dockerfile_location:
     :param host_tmp_dir:
     :param student_token_file:
@@ -31,9 +34,10 @@ def student_token_file_runner(host_tmp_dir, student_token_file, instructor_grade
     assert os.path.exists(student_token_file)
     assert os.path.exists(instructor_grade_script)
     start = time.time()
-
-    with open(student_token_file, 'rb') as f:
-        results = pickle.load(f)
+    from unitgrade_private import load_token
+    results, _ = load_token(student_token_file)
+    # with open(student_token_file, 'rb') as f:
+    #     results = pickle.load(f)
     sources = results['sources'][0]
 
     with io.BytesIO(sources['zipfile']) as zb:
