@@ -19,6 +19,7 @@ def moss_prepare(whitelist_dir, submission_dir):
     white_hashes = set()
     for k, py in enumerate(pys):
         id = file_id(py)
+        print("> Whitelisting", py)
         if id not in white_hashes:
             white_hashes.add(id)
             shutil.copy(py, tmp_base + f"/{k}_" + os.path.basename(py))
@@ -41,7 +42,7 @@ def moss_prepare(whitelist_dir, submission_dir):
 
 
 def ensure_tokens_unpacked(directory, flat=True):
-    tokens = glob.glob(directory + "/*/*.token", recursive=True)
+    tokens = glob.glob(directory + "/**/*.token", recursive=True)
     for t in tokens:
         unpack_sources_from_token(t)
 
